<?php
/**
 * Geral\Repositories
 *
 * @category Php
 * @package  Geral\Repositories
 * @author   matthaeuscarvalho <matthaeus.carvalho@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Geral\Repositories;

/**
 * Class Marca
 *
 * @category Php
 * @package  Geral\Repositories
 * @author   matthaeuscarvalho <matthaeus.carvalho@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class Marca extends \Doctrine\ORM\EntityRepository
{
    /**
     * Consulta Marca Vinculada ao Produto
     * @param  String $nrorg     Nrorg
     * @param  String $cdproduto Produto
     * @param  String $cdmarca   Marca
     * @return array
     * @throws \Exception
     */
    public function consultaMarcaVinculadaProduto($nrorg, $cdproduto, $cdmarca)
    {
        $sql = "SELECT
                  MARCA.CDMARCA,
                  MARCA.NMMARCA
                FROM
                  MARCA,
                  MARCPROD,
                  PRODUTO
                WHERE
                  MARCPROD.CDPRODUTO = PRODUTO.CDPRODUTO   AND
                  :P_CDPRODUTO LIKE PRODUTO.CDARVPROD||'%' AND
                  MARCPROD.NRORG   = :P_NRORG              AND
                  MARCPROD.CDMARCA = :P_CDMARCA            AND
                  MARCPROD.NRORG     = PRODUTO.NRORG       AND
                  MARCPROD.CDMARCA = MARCA.CDMARCA";

        $paramsWhere = array(
            'P_NRORG'     => $nrorg,
            'P_CDPRODUTO' => $cdproduto,
            'P_CDMARCA'   => $cdmarca,
        );

        try {
            return $this->_em->getConnection()->fetchAll($sql, $paramsWhere);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Consulta Qualificacao Vencida
     *
     * @param String $nrorg           Nrorg
     * @param String $cdfilial        Filial
     * @param String $cdproduto       Produto
     * @param String $cdmarca         Marca
     * @param String $data_autor_forn Data Autor Fornecedor
     *
     * @return array
     * @throws \Exception
     */
    public function consultaQualificacaoVencida(
        $nrorg, $cdfilial, $cdproduto, $cdmarca, $data_autor_forn
    ) {
        $sql = "SELECT
                   QFOMARPROD.CDMARCA
                FROM
                   QFOMARPROD,
                   PARASUPRI
                WHERE
                  (QFOMARPROD.NRORG        = :P_NRORG)           AND
                  (QFOMARPROD.CDPRODUTO    = :P_CDPRODUTO)       AND
                  (QFOMARPROD.CDMARCA      = :P_CDMARCA)         AND
                  (PARASUPRI.CDFILIAL      = :P_CDFILIAL)        AND
                  ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR
                  ((QFOMARPROD.IDAPRMARPRO = 'S')                AND
                  ((PARASUPRI.IDULTIDTVALQ = 'M'                 AND
                  TO_DATE(:P_DTAUTOFORN)   > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                  (PARASUPRI.IDULTIDTVALQ  = 'D'                 AND
                  TO_DATE(:P_DTAUTOFORN)   > QFOMARPROD.DTVALAPROVA)) ) )

                UNION

                SELECT
                  PARASUPRI.CDMARCA
                FROM
                  PARASUPRI
                WHERE
                  PARASUPRI.NRORG       = :P_NRORG    AND
                  PARASUPRI.CDFILIAL    = :P_CDFILIAL AND
                  PARASUPRI.IDMARSEMQUA = 'S'         AND
                  NOT EXISTS
                   (SELECT
                      QFOMARPROD.CDMARCA
                    FROM
                      QFOMARPROD
                    WHERE
                      QFOMARPROD.NRORG       = :P_NRORG     AND
                      QFOMARPROD.CDPRODUTO   = :P_CDPRODUTO AND
                      QFOMARPROD.CDMARCA     = :P_CDMARCA)";

        $paramsWhere = array(
            'P_NRORG'      => $nrorg,
            'P_CDFILIAL'   => $cdfilial,
            'P_CDPRODUTO'  => $cdproduto,
            'P_CDMARCA'    => $cdmarca,
            'P_DTAUTOFORN' => $data_autor_forn,
        );

        try {
            return $this->_em->getConnection()->fetchAll($sql, $paramsWhere);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Verifica Qualificacao Marca Produto
     *
     * @param String $nrorg     Organização
     * @param String $cdmarca   Marca
     * @param String $tcdmarca  Todas Marcas
     * @param String $cdprodini Produto Inicial
     * @param String $cdprodfin Produto final
     * @param String $tproduto  Todos Produtos
     * @param String $cdfilial  Filial
     * @param String $dtcol     Data da Coleta
     *
     * @throws \Exception
     * @return array
     */
    public function verificaQualificacaoMarcaProduto(
        $nrorg, $cdmarca, $tcdmarca, $cdprodini, $cdprodfin,
        $tproduto, $cdfilial, $dtcol
    ) {
        $sql = <<<SQL
SELECT
    CDMARCA
FROM
    MARCA
WHERE
    (INSTR(:P_CDMARCA, MARCA.CDMARCA) <> 0 OR :P_TCDMARCA = 'T')
AND
    MARCA.NRORG = :P_NRORG
AND NOT EXISTS
    (
    SELECT
        QFOMARPROD.CDMARCA
    FROM
        QFOMARPROD,
        PRODUTO,
        PARASUPRI
    WHERE
        (QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO)
        AND (MARCA.CDMARCA          = QFOMARPROD.CDMARCA)
        AND ((PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN)
        OR (:P_TPRODUTO              = 'T'))
        AND (PARASUPRI.CDFILIAL      = :P_CDFILIAL )
        AND (
            (QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO   = 'N')
            OR (
                (QFOMARPROD.IDAPRMARPRO  = 'S')
                AND (
                    (PARASUPRI.IDULTIDTVALQ = 'M'
                    AND TO_DATE(:P_DTCOL)        > LAST_DAY(QFOMARPROD.DTVALAPROVA))
                    OR (PARASUPRI.IDULTIDTVALQ   = 'D'
                    AND TO_DATE(:P_DTCOL)        > QFOMARPROD.DTVALAPROVA)
                    )
                )
            )
    )
AND EXISTS
    (
        SELECT
            QFOMARPROD.CDMARCA
        FROM
            QFOMARPROD,
            PRODUTO
        WHERE
            ((PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN) OR (:P_TPRODUTO = 'T'))
            AND QFOMARPROD.CDMARCA   = MARCA.CDMARCA
            AND QFOMARPROD.CDPRODUTO = PRODUTO.CDPRODUTO

        UNION

        SELECT
            PARASUPRI.CDMARCA
        FROM
            PARASUPRI
        WHERE
            PARASUPRI.CDFILIAL   = :P_CDFILIAL
            AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA  IS NULL)
    )
SQL;
        $params = array(
            'P_CDMARCA' => $cdmarca,
            'P_TCDMARCA' => $tcdmarca,
            'P_CDPRODINI' => $cdprodini,
            'P_CDPRODFIN' => $cdprodfin,
            'P_TPRODUTO' => $tproduto,
            'P_CDFILIAL' => $cdfilial,
            'P_DTCOL' => $dtcol,
            'P_NRORG' => $nrorg
        );

        try {
            return self::getEntityManager()->getConnection()->fetchArray($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}