/**************************************************************************************************/
/*                                   Sistemas Integrados TECNISA                                  */
/*                                                                                                */
/*                                   PARMETROS DE PLANEJAMENTO                                   */
/*                                                                                                */
/**************************************************************************************************/
/*                                                                                                */
/* NOME: ATUALIZA_PARAMPLANEJA_PDR                                                                */
/*                                                                                                */
/* DESCRIO: ATUALIZA OS DADOS DA TABELA "PARAMPLANEJA" A PARTIR DO PARMETROS DA FILIAL PADRAO. */
/*                                                                                                */
/* CRIAO: 17/05/2009 - GLEYDSON ISRAEL DA SILVA GAZOLA                                          */
/*                                                                                                */
/**************************************************************************************************/
/* PARAMETROS: P_CDFILIAL - Cdigo da Filial                                                      */
/**************************************************************************************************/

create or replace
PROCEDURE ATUALIZA_PARAMPLANEJA_PDR(P_CDFILIAL IN FILIAL.CDFILIAL%TYPE)
AS
   V_UPDATE_TEXT_PARAMPLANEJA VARCHAR2(8000);
   V_INSERT_TEXT_PARAMPLANEJA VARCHAR2(8000);
   V_CDFILIAL_PADRAO FILIAL.CDFILIAL%TYPE;
   V_IDUTREQUPRAT_PADRAO PARAMPLANEJA.IDUTREQUPRAT%TYPE;
   V_CDFILCONSFIX_PADRAO PARAMPLANEJA.CDFILCONSFIX%TYPE;
   V_CDPRACONSFIX_PADRAO PARAMPLANEJA.CDPRACONSFIX%TYPE;
   V_CDSETCONPERC_PADRAO PARAMPLANEJA.CDSETCONPERC%TYPE;
   V_CDTCACONSFIX_PADRAO PARAMPLANEJA.CDTCACONSFIX%TYPE;
   V_CDSERVRETPME_PADRAO PARAMPLANEJA.CDSERVRETPME%TYPE;
   V_CDSETCONFIXO_PADRAO PARAMPLANEJA.CDSETCONFIXO%TYPE;
   V_CDFILCONSPER_PADRAO PARAMPLANEJA.CDFILCONSPER%TYPE;
   V_CDPRACONSPER_PADRAO PARAMPLANEJA.CDPRACONSPER%TYPE;
   V_CDTCACONSPER_PADRAO PARAMPLANEJA.CDTCACONSPER%TYPE;
   V_CDSETORCOZ_DESTINO SETORCOZ.CDSETORCOZ%TYPE;
   V_CDTIPOCARD_DESTINO TIPOCARD.CDTIPOCARD%TYPE;
   V_CDSERVFILI_DESTINO SERVICO.CDSERVFILI%TYPE;
   V_CDPRATO_DESTINO PRATO.CDPRATO%TYPE;
BEGIN
   /* SELECIONA A FILIAL PADRAO */
   BEGIN
      SELECT CDFILIPADRAO
        INTO V_CDFILIAL_PADRAO
        FROM PARAMGERAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_CDFILIAL_PADRAO := NULL;
   END;
   IF V_CDFILIAL_PADRAO IS NOT NULL THEN
      /* SELECIONA OS VALORES DA PARAMPLANEJA PARA A FILIAL PADRAO*/
      BEGIN
         SELECT IDUTREQUPRAT, 
                CDFILCONSFIX, 
                CDPRACONSFIX, 
                CDSETCONPERC, 
                CDTCACONSFIX, 
                CDSERVRETPME, 
                CDSETCONFIXO, 
                CDFILCONSPER, 
                CDPRACONSPER, 
                CDTCACONSPER 
           INTO V_IDUTREQUPRAT_PADRAO, 
                V_CDFILCONSFIX_PADRAO, 
                V_CDPRACONSFIX_PADRAO, 
                V_CDSETCONPERC_PADRAO,
                V_CDTCACONSFIX_PADRAO, 
                V_CDSERVRETPME_PADRAO, 
                V_CDSETCONFIXO_PADRAO, 
                V_CDFILCONSPER_PADRAO, 
                V_CDPRACONSPER_PADRAO, 
                V_CDTCACONSPER_PADRAO
           FROM PARAMPLANEJA
          WHERE CDFILIAL = V_CDFILIAL_PADRAO;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_IDUTREQUPRAT_PADRAO := NULL;
            V_CDFILCONSFIX_PADRAO := NULL;
            V_CDPRACONSFIX_PADRAO := NULL;
            V_CDSETCONPERC_PADRAO := NULL;
            V_CDTCACONSFIX_PADRAO := NULL;
            V_CDSERVRETPME_PADRAO := NULL;
            V_CDSETCONFIXO_PADRAO := NULL;
            V_CDFILCONSPER_PADRAO := NULL;
            V_CDPRACONSPER_PADRAO := NULL;
            V_CDTCACONSPER_PADRAO := NULL;
      END;
      /* SELECIONA AS FILIAIS QUE SERO ALTERADAS PARA UTLIZAREM OS PARAMETROS DA FILIAL PADRAO */
      FOR C_INSPARAM IN(SELECT CDFILIAL
                          FROM PARAMFILIPADR
                         WHERE IDTABPARAMFILI = 'S'
                           AND NMTABPARAMFILI = 'PARAMPLANEJA'
                           AND CDFILIAL <> V_CDFILIAL_PADRAO
                           AND CDFILIAL = NVL(P_CDFILIAL, CDFILIAL)) LOOP
         V_UPDATE_TEXT_PARAMPLANEJA := 'INSERT INTO PARAMPLANEJA (';
         V_INSERT_TEXT_PARAMPLANEJA := '(SELECT ' ;
         /* SELECIONA OS CAMPOS DA TABELA 'PARAMPLANEJA' */
         FOR C_CAMPO IN (SELECT COLUMN_NAME
                           FROM USER_TAB_COLUMNS
                          WHERE TABLE_NAME = 'PARAMPLANEJA') LOOP
            /* SER FEITA A CONSISTNCIA DO BANCO, EVITADOR ASSIM GRAVAR DADOS INEXISTENTES PARA A FILIAL FILHA */
            /* FKPLA00141SETORCOZ */
            IF C_CAMPO.COLUMN_NAME = 'CDSETCONPERC' THEN 
               BEGIN
                  SELECT CDSETORCOZ
                    INTO V_CDSETORCOZ_DESTINO
                    FROM SETORCOZ
                   WHERE CDFILIAL = C_INSPARAM.CDFILIAL
                     AND CDSETORCOZ = V_CDSETCONPERC_PADRAO;
               EXCEPTION
                  WHEN NO_DATA_FOUND THEN
                     V_CDSETORCOZ_DESTINO := NULL;
               END;
               IF V_CDSETORCOZ_DESTINO IS NOT NULL THEN
                  V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                  V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
               END IF;
            ELSE
               /* FKPME00055TIPOCARD */
               IF C_CAMPO.COLUMN_NAME = 'CDTCACONSFIX' THEN 
                  BEGIN
                     SELECT CDTIPOCARD
                       INTO V_CDTIPOCARD_DESTINO
                       FROM TIPOCARD
                      WHERE CDFILCENTPME = C_INSPARAM.CDFILIAL
                        AND CDTIPOCARD = V_CDTCACONSFIX_PADRAO;
                  EXCEPTION
                     WHEN NO_DATA_FOUND THEN
                        V_CDTIPOCARD_DESTINO := NULL;
                  END;
                  IF V_CDTIPOCARD_DESTINO IS NOT NULL THEN
                     V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                     V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                  END IF;
               ELSE
                  /* FKPME00032SERVICO */
                  IF C_CAMPO.COLUMN_NAME = 'CDSERVRETPME' THEN 
                     BEGIN
                        SELECT CDSERVFILI
                          INTO V_CDSERVFILI_DESTINO
                          FROM SERVICO
                         WHERE CDFILIAL = C_INSPARAM.CDFILIAL
                           AND CDSERVFILI = V_CDSERVRETPME_PADRAO;
                     EXCEPTION
                        WHEN NO_DATA_FOUND THEN
                           V_CDSERVFILI_DESTINO := NULL;
                     END;
                     IF V_CDSERVFILI_DESTINO IS NOT NULL THEN
                        V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                        V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                     END IF;
                  ELSE
                     /* FKPLA00140SETORCOZ */
                     IF C_CAMPO.COLUMN_NAME = 'CDSETCONFIXO' THEN 
                        BEGIN
                           SELECT CDSETORCOZ
                             INTO V_CDSETORCOZ_DESTINO
                             FROM SETORCOZ
                            WHERE CDFILIAL = C_INSPARAM.CDFILIAL
                              AND CDSETORCOZ = V_CDSETCONFIXO_PADRAO;
                        EXCEPTION
                           WHEN NO_DATA_FOUND THEN
                              V_CDSETORCOZ_DESTINO := NULL;
                        END;
                        IF V_CDSETORCOZ_DESTINO IS NOT NULL THEN
                           V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                           V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                        END IF;
                     ELSE
                        /* FKPLA00240PRATO */
                        IF (C_CAMPO.COLUMN_NAME = 'CDFILCONSPER') OR (C_CAMPO.COLUMN_NAME = 'CDPRACONSPER') THEN 
                           IF V_CDFILCONSPER_PADRAO = 'P' THEN
                              V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                              V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                           ELSE
                              BEGIN
                                 SELECT CDPRATO
                                   INTO V_CDPRATO_DESTINO
                                   FROM PRATO
                                  WHERE CDFILAUXPRAT = C_INSPARAM.CDFILIAL
                                    AND CDPRATO = V_CDPRACONSPER_PADRAO;
                              EXCEPTION
                                 WHEN NO_DATA_FOUND THEN
                                    V_CDPRATO_DESTINO := NULL;
                              END;
                              IF V_CDPRATO_DESTINO IS NOT NULL THEN
                                 V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                 V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                              END IF;
                           END IF;
                        ELSE
                           /* FKPME00056TIPOCARD */
                           IF C_CAMPO.COLUMN_NAME = 'CDTCACONSPER' THEN
                              BEGIN
                                 SELECT CDTIPOCARD
                                   INTO V_CDTIPOCARD_DESTINO
                                   FROM TIPOCARD
                                  WHERE CDFILCENTPME = C_INSPARAM.CDFILIAL
                                    AND CDTIPOCARD = V_CDTCACONSPER_PADRAO;
                              EXCEPTION
                                 WHEN NO_DATA_FOUND THEN
                                    V_CDTIPOCARD_DESTINO := NULL;
                              END;
                              IF V_CDTIPOCARD_DESTINO IS NOT NULL THEN
                                 V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                 V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                              END IF;
                           ELSE
                              /* FKPLA00238PRATO */
                              IF (C_CAMPO.COLUMN_NAME = 'CDFILCONSFIX') OR (C_CAMPO.COLUMN_NAME = 'CDPRACONSFIX') THEN 
                                 IF V_CDFILCONSFIX_PADRAO = 'P' THEN
                                    V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                    V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                 ELSE 
                                    BEGIN
                                       SELECT CDPRATO
                                         INTO V_CDPRATO_DESTINO
                                         FROM PRATO
                                        WHERE CDFILAUXPRAT = C_INSPARAM.CDFILIAL
                                          AND CDPRATO = V_CDPRACONSFIX_PADRAO;
                                    EXCEPTION
                                       WHEN NO_DATA_FOUND THEN
                                          V_CDPRATO_DESTINO := NULL;
                                    END;
                                    IF V_CDPRATO_DESTINO IS NOT NULL THEN
                                       V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                       V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                    END IF;
                                 END IF;
                              ELSE
                                 IF NOT (C_CAMPO.COLUMN_NAME = 'CDFILIAL') THEN
                                    V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                    V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA || C_CAMPO.COLUMN_NAME || ', ';
                                 END IF;   
                              END IF;
                           END IF;
                        END IF;
                     END IF;
                  END IF;
               END IF;
            END IF;
         END LOOP;
         /* DELETA O REGISTRO DA TABELA */
         DELETE FROM PARAMPLANEJA PA
          WHERE CDFILIAL = C_INSPARAM.CDFILIAL;
         /* EXECUTA UMA INSERO COM OS DADOS DA FILIAL PADRO */
         V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA||'CDFILIAL) ';
         V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA||''''||C_INSPARAM.CDFILIAL||''''||' ';
         V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA ||'FROM PARAMPLANEJA PA ';
         V_INSERT_TEXT_PARAMPLANEJA := V_INSERT_TEXT_PARAMPLANEJA ||'WHERE PA.CDFILIAL = '||''''||V_CDFILIAL_PADRAO||''''||')';
         V_UPDATE_TEXT_PARAMPLANEJA := V_UPDATE_TEXT_PARAMPLANEJA || V_INSERT_TEXT_PARAMPLANEJA;
         EXECUTE IMMEDIATE V_UPDATE_TEXT_PARAMPLANEJA;
         /* GRAVA 'S' PARA O CAMPO "IDUTREQUPRAT" PARA TODOS OS SERVIOS DA FILIAL CASO A FILIAL PADRAO UTILIZA
         A OPO DE "OBRIGAR A FAZER REQUISIO/RETIRADA POR PRATO" */
         IF V_IDUTREQUPRAT_PADRAO = 'S' THEN
            UPDATE SERVICO
               SET IDUTRETIPRAT = 'S'
             WHERE CDFILIAL = C_INSPARAM.CDFILIAL;
         END IF;
      END LOOP;
      COMMIT;
   END IF;   
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ATUALIZA_PARAMPLANEJA_PDR','5.07.006'); END;
/
