/*-- ================================================================== --
-- SISTEMA         : PONTO DE VENDA                                   --
-- DATA DA CRIAO : 05/09/2002                                       --
-- CRIAO         : Renata Diniz                                     --
-- OBJETIVOS       : Calcula Margem Bruta                             --
-- ================================================================== --
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'MARGEM_BRUTA' AND
	        TYPE = 'P'                    AND
	        U.UID = O.UID                 AND
	        U.NAME = USER)

   DROP PROCEDURE MARGEM_BRUTA
   GO

CREATE PROCEDURE MARGEM_BRUTA
  @P_CDEMPRESA      VARCHAR(2),
  @P_DTVENDAINI     DATETIME,
  @P_DTVENDAFIN     DATETIME,
  @P_CDFILIAL       VARCHAR(4),
  @P_FILIPROC       VARCHAR(4),
  @P_CDCAIXA        VARCHAR(2000),
  @P_TCDCAIXA       VARCHAR(1),
  @P_CDLOJA         VARCHAR(10),
  @P_TCDLOJA        VARCHAR(1),
  @P_CDSUBGRPROD    VARCHAR(2000),
  @P_TCDSUBGRPROD   VARCHAR(1),
  @P_TIPOCUSTO      NUMERIC,
  @P_MARGEMBRUTA    NUMERIC OUTPUT,
  @P_LOJA           VARCHAR(10) = NULL

AS

  DECLARE @V_VRTOTALMARGEMBRUTA  FLOAT;
  DECLARE @V_CUSTOACUMULADO_AUX  FLOAT;
  DECLARE @V_CUSTOACUMULADO      FLOAT;
  DECLARE @V_NRPRODUTOS          FLOAT;
  DECLARE @V_RESULT              VARCHAR(4);
  DECLARE @V_VRCUSTO             FLOAT;

  DECLARE @C_CDFILIAL     VARCHAR(04);
  DECLARE @C_CDPRODUTO    VARCHAR(10);
  DECLARE @C_QTPRODVEND   FLOAT;
  DECLARE @C_VRPREBRUTO   FLOAT;
  DECLARE @C_VRPRELIQ     FLOAT;

BEGIN

   SET @V_VRTOTALMARGEMBRUTA = 0;
   SET @V_CUSTOACUMULADO_AUX = 0;
   SET @V_CUSTOACUMULADO     = 0;

   DECLARE C_PRODUTO CURSOR FOR
      SELECT  VE.CDFILIAL,IT.CDPRODUTO, SUM(ISNULL(IT.QTPRODVEND,0)) AS QTPRODVEND,
              ISNULL(IT.VRUNITVEND, 0) + ISNULL(IT.VRUNITVENDCL, 0) AS VRPREBRUTO,
              ((ISNULL(IT.VRUNITVEND, 0) + ISNULL(IT.VRUNITVENDCL, 0)) -
              ISNULL(IT.VRDESITVEND, 0)) - (((ISNULL(IT.VRUNITVEND, 0) +
              ISNULL(IT.VRUNITVENDCL,0))) * ISNULL(IM.VRPEALPRODIT, 0) / 100) AS VRPRELIQ
      FROM   VENDA VE, CAIXA CA,
         ITEMVENDA IT LEFT JOIN (SELECT SUM(IM.VRPEALPRODIT) AS VRPEALPRODIT, IM.CDFILIAL, IM.CDCAIXA,
                                        IM.NRSEQVENDA,IM.NRSEQUITVEND
                                 FROM ITVENDAIMPOS IM, ITEMVENDA IT
                                 WHERE (IM.CDFILIAL     = IT.CDFILIAL    ) AND
                                       (IM.CDCAIXA      = IT.CDCAIXA     ) AND
                                       (IM.NRSEQVENDA   = IT.NRSEQVENDA  ) AND
                                       (IM.NRSEQUITVEND = IT.NRSEQUITVEND)
                                 GROUP BY IM.CDFILIAL, IM.CDCAIXA, IM.NRSEQVENDA,
                                          IM.NRSEQUITVEND ) IM ON(IM.CDFILIAL     = IT.CDFILIAL)   AND
                                                                 (IM.CDCAIXA      = IT.CDCAIXA )   AND
                                                                 (IM.NRSEQVENDA   = IT.NRSEQVENDA) AND
                                                                 (IM.NRSEQUITVEND = IT.NRSEQUITVEND)

      WHERE VE.CDEMPRESA = @P_CDEMPRESA
         AND VE.CDFILIAL  = @P_CDFILIAL
         AND ((CHARINDEX(CA.CDLOJA, @P_CDLOJA              ) > 0) OR (@P_TCDLOJA      = 'T'))
         AND ((CHARINDEX(VE.CDCAIXA, @P_CDCAIXA            ) > 0) OR (@P_TCDCAIXA     = 'T'))
         AND ((CHARINDEX(IT.CDSUBGRPROD,@P_CDSUBGRPROD) > 0) OR (@P_TCDSUBGRPROD = 'T'))
         AND CONVERT(DATETIME, CONVERT(VARCHAR, VE.DTENTRVENDA, 103)) BETWEEN @P_DTVENDAINI AND @P_DTVENDAFIN
         AND VE.CDFILIAL   = IT.CDFILIAL
         AND VE.CDCAIXA    = IT.CDCAIXA
         AND VE.NRSEQVENDA = IT.NRSEQVENDA
         AND VE.CDCAIXA    = CA.CDCAIXA
         AND VE.IDSITUVENDA <> 'C'
         AND VE.CDFILIAL   = CA.CDFILIAL
       GROUP BY
          VE.CDFILIAL,IT.CDPRODUTO,
          (ISNULL(IT.VRUNITVEND, 0) + ISNULL(IT.VRUNITVENDCL, 0)),
          ((ISNULL(IT.VRUNITVEND, 0) + ISNULL(IT.VRUNITVENDCL, 0)) -
            ISNULL(IT.VRDESITVEND, 0)) - (((ISNULL(IT.VRUNITVEND, 0) +
            ISNULL(IT.VRUNITVENDCL,0))) * ISNULL(IM.VRPEALPRODIT, 0) / 100)
       ORDER BY
          VE.CDFILIAL,IT.CDPRODUTO

   OPEN C_PRODUTO;
   FETCH NEXT FROM C_PRODUTO INTO @C_CDFILIAL,@C_CDPRODUTO, @C_QTPRODVEND,
                                  @C_VRPREBRUTO, @C_VRPRELIQ;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      /* VERIFICA COMPOSICAO LOCAL */
      SELECT @V_NRPRODUTOS = COUNT(*)
      FROM   ROTFABLOCAL
      WHERE (CDFILIAL  = @P_CDFILIAL ) AND
            (CDPRODUTO = @C_CDPRODUTO);

      IF @V_NRPRODUTOS > 0 BEGIN
         SET @V_RESULT = @P_CDFILIAL
      END ELSE BEGIN
         SET @V_RESULT = 'P'
      END;

      EXEC CUSTO_COMP_PROD @C_CDPRODUTO, @P_CDFILIAL, @P_FILIPROC, @P_TIPOCUSTO,
                           1, @P_LOJA, @V_VRCUSTO;

      SET @V_CUSTOACUMULADO_AUX  = ISNULL(@V_VRCUSTO,0);
      SET @V_CUSTOACUMULADO      = @V_CUSTOACUMULADO + (@V_CUSTOACUMULADO_AUX * @C_QTPRODVEND);
      SET @V_VRTOTALMARGEMBRUTA  = @V_VRTOTALMARGEMBRUTA + (@C_QTPRODVEND * @C_VRPRELIQ) - (@V_CUSTOACUMULADO_AUX * @C_QTPRODVEND);
      SET @V_CUSTOACUMULADO_AUX  = 0;

      FETCH NEXT FROM C_PRODUTO INTO @C_CDFILIAL,@C_CDPRODUTO, @C_QTPRODVEND,@C_VRPREBRUTO, @C_VRPRELIQ;
   END;
   CLOSE C_PRODUTO;
   DEALLOCATE C_PRODUTO;

   SET @P_MARGEMBRUTA = @V_VRTOTALMARGEMBRUTA;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'MARGEM_BRUTA','4.11.039';
GO

