/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: SEMANAL_RECORRENTE_DTENTR                                            */
/*                                                                            */
/* Descrio:                                                                 */
/* Calcula datas de entrega para um determinado mes baseando-se na            */
/* Periodicidade de Entrega cujo tipo  "Recorrente - Semanal"                */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/* 19/07/2007 - Marcelo Alexsandro Souza Silva                                */
/*                                                                            */
/******************************************************************************/
/* PARAMETROS:                                                                */
/*                                                                            */
/* P_CDFILIAL     - Cdigo da Filial                                          */
/* P_CDPERIENTR   - Cdigo da Periodicidade de Entrega                        */
/* P_DTINICIAL    - Data do Inicio do Mes                                     */
/* P_NRMESES      - Numero de meses a serem calculados                        */
/******************************************************************************/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'SEMANAL_RECORRENTE_DTENTR'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
  DROP PROCEDURE SEMANAL_RECORRENTE_DTENTR
  GO

CREATE PROCEDURE SEMANAL_RECORRENTE_DTENTR
   @P_CDFILIAL     VARCHAR(4),
   @P_CDPERIENTR   VARCHAR(2),
   @P_DTINICIAL    DATETIME,
   @P_NRMESES      INT,
   @P_DTPROCESSA   DATETIME
AS
   DECLARE @V_CONTA          NUMERIC;
   DECLARE @V_INTERVALO      NUMERIC;
   DECLARE @V_DIENTREGA      NUMERIC;
   DECLARE @V_AUXDIENTREGA   NUMERIC;
   DECLARE @V_AUX            NUMERIC;
   DECLARE @V_CONTAUXI       NUMERIC;

   DECLARE @V_MINENTREGA     VARCHAR(2);
   DECLARE @V_MAXENTREGA     VARCHAR(2);
   DECLARE @V_IDDOMPERIREC   VARCHAR(1);
   DECLARE @V_IDSEGPERIREC   VARCHAR(1);
   DECLARE @V_IDTERPERIREC   VARCHAR(1);
   DECLARE @V_IDQUAPERIREC   VARCHAR(1);
   DECLARE @V_IDQUIPERIREC   VARCHAR(1);
   DECLARE @V_IDSEXPERIREC   VARCHAR(1);
   DECLARE @V_IDSABPERIREC   VARCHAR(1);
   DECLARE @V_EXISTECALECOMP VARCHAR(1);
   DECLARE @V_SOMENTEDIAUTIL VARCHAR(1);

   DECLARE @V_SEMANA_IDDOMPERIREC VARCHAR(1);
   DECLARE @V_SEMANA_IDSEGPERIREC VARCHAR(1);
   DECLARE @V_SEMANA_IDTERPERIREC VARCHAR(1);
   DECLARE @V_SEMANA_IDQUAPERIREC VARCHAR(1);
   DECLARE @V_SEMANA_IDQUIPERIREC VARCHAR(1);
   DECLARE @V_SEMANA_IDSEXPERIREC VARCHAR(1);
   DECLARE @V_SEMANA_IDSABPERIREC VARCHAR(1);

   DECLARE @V_ANTPROXENTR_CDFILIAL   VARCHAR(4);
   DECLARE @V_ANTPROXENTR_CDPERIENTR VARCHAR(2);
   DECLARE @V_ANTPROXENTR_DTENTREGA  DATETIME;

   DECLARE @V_ANO            VARCHAR(4);

   DECLARE @V_DTMAXENTREGA DATETIME;
   DECLARE @V_DTAUX        DATETIME;
   DECLARE @V_DTAUX2       DATETIME;
   DECLARE @V_DTORIGINAL   DATETIME;
   DECLARE @VDATAPROX      DATETIME;
   DECLARE @V_DTINI_N_FERI DATETIME;
   DECLARE @V_DTFIN_N_FERI DATETIME;
BEGIN
   SET @V_DTINI_N_FERI = @P_DTINICIAL - 7;
   SET @V_DTFIN_N_FERI = @P_DTINICIAL + 7;
   SET @V_ANO = SUBSTRING(CONVERT(VARCHAR, @P_DTINICIAL, 103), 7, 4);

   IF @P_DTINICIAL > @P_DTPROCESSA BEGIN
      DELETE FROM CALECOMP
      WHERE CDFILIAL   = @P_CDFILIAL
        AND CDPERIENTR = @P_CDPERIENTR
        AND DTENTREGA BETWEEN (@P_DTINICIAL) AND CONVERT(DATETIME, '31/12/'+@V_ANO, 103);
   END
   ELSE BEGIN
      DELETE FROM CALECOMP
      WHERE CDFILIAL   = @P_CDFILIAL
        AND CDPERIENTR = @P_CDPERIENTR
        AND DTENTREGA BETWEEN (@P_DTPROCESSA) AND CONVERT(DATETIME, '31/12/'+@V_ANO, 103);
   END;

   SELECT @V_CONTA = COUNT(*), @V_MINENTREGA = MIN(DIENTREGA), @V_MAXENTREGA = MAX(DIENTREGA)
   FROM DIASENTR D
   WHERE D.CDPERIENTR = @P_CDPERIENTR;
   SET @V_EXISTECALECOMP = 'S';
   SELECT
      @V_IDDOMPERIREC   = ISNULL(MAX(IDDOMPERIREC),'N'),
      @V_IDSEGPERIREC   = ISNULL(MAX(IDSEGPERIREC),'N'),
      @V_IDTERPERIREC   = ISNULL(MAX(IDTERPERIREC),'N'),
      @V_IDQUAPERIREC   = ISNULL(MAX(IDQUAPERIREC),'N'),
      @V_IDQUIPERIREC   = ISNULL(MAX(IDQUIPERIREC),'N'),
      @V_IDSEXPERIREC   = ISNULL(MAX(IDSEXPERIREC),'N'),
      @V_IDSABPERIREC   = ISNULL(MAX(IDSABPERIREC),'N'),
      @V_SOMENTEDIAUTIL = ISNULL(MAX(IDDIANUTIL)  ,'S')
   FROM DIASENTR, PERIENTR
   WHERE DIASENTR.CDPERIENTR = @P_CDPERIENTR
     AND DIASENTR.DIENTREGA  = @V_MINENTREGA
     AND PERIENTR.CDPERIENTR = DIASENTR.CDPERIENTR;

   SET @V_INTERVALO = 7 * @V_CONTA;

   IF @V_CONTA > 0 BEGIN
      SELECT
         @V_DTMAXENTREGA = MAX(DTENTREGA)
      FROM
         CALECOMP
      WHERE CALECOMP.CDFILIAL   = @P_CDFILIAL
        AND CALECOMP.CDPERIENTR = @P_CDPERIENTR
        AND CALECOMP.DTENTREGA <= @P_DTINICIAL
        AND NOT EXISTS (SELECT 1
                        FROM FERICOMP
                        WHERE FERICOMP.CDFILIAL   = CALECOMP.CDFILIAL
                          AND FERICOMP.DTFERICOMP BETWEEN @V_DTINI_N_FERI AND @V_DTFIN_N_FERI);
      IF @V_DTMAXENTREGA IS NULL BEGIN
         SELECT
            @V_DTMAXENTREGA = MAX(DTENTREGA)
         FROM
            CALECOMP
         WHERE CALECOMP.CDPERIENTR = @P_CDPERIENTR
           AND CALECOMP.DTENTREGA <= @P_DTINICIAL
           AND NOT EXISTS (SELECT 1
                           FROM FERICOMP
                           WHERE FERICOMP.CDFILIAL   = CALECOMP.CDFILIAL
                             AND FERICOMP.DTFERICOMP BETWEEN @V_DTINI_N_FERI AND @V_DTFIN_N_FERI);
      END;
      IF @V_DTMAXENTREGA IS NULL BEGIN
         SET @V_EXISTECALECOMP = 'N';
         SET @V_DTMAXENTREGA   = CONVERT(DATETIME,'01/01/'+ @V_ANO, 103);
      END;

      SET @V_AUXDIENTREGA = NULL;
      WHILE (@V_AUXDIENTREGA IS NULL) BEGIN
         SELECT
            @V_DIENTREGA = DATEPART(DW, @V_DTMAXENTREGA);

         SELECT @V_AUXDIENTREGA = MAX(DIENTREGA)
         FROM DIASENTR
         WHERE CDPERIENTR = @P_CDPERIENTR AND
               (
                CASE ISNULL(IDDOMPERIREC,'N')
                  WHEN 'S' THEN 1
                  ELSE  8
                END = @V_DIENTREGA OR
                CASE ISNULL(IDSEGPERIREC,'N')
                  WHEN 'S' THEN 2
                  ELSE  8
                END = @V_DIENTREGA OR
                CASE ISNULL(IDTERPERIREC,'N')
                  WHEN 'S' THEN 3
                  ELSE  8
                END = @V_DIENTREGA OR
                CASE ISNULL(IDQUAPERIREC,'N')
                  WHEN 'S' THEN 4
                  ELSE  8
                END = @V_DIENTREGA OR
                CASE ISNULL(IDQUIPERIREC,'N')
                  WHEN 'S' THEN 5
                  ELSE  8
                END = @V_DIENTREGA OR
                CASE ISNULL(IDSEXPERIREC,'N')
                  WHEN 'S' THEN 6
                  ELSE  8
                END = @V_DIENTREGA OR
                CASE ISNULL(IDSABPERIREC,'N')
                  WHEN 'S' THEN 7
                  ELSE  8
                END = @V_DIENTREGA
                );
         IF @V_AUXDIENTREGA IS NULL BEGIN
            IF @V_EXISTECALECOMP = 'N' BEGIN
               SET @V_DTMAXENTREGA = @V_DTMAXENTREGA + 1;
            END
            ELSE BEGIN
               SET @V_DTMAXENTREGA = @V_DTMAXENTREGA - 1;
            END;
         END;
      END;
      IF @V_EXISTECALECOMP = 'S' BEGIN
         IF @V_AUXDIENTREGA > CONVERT(NUMERIC, @V_MINENTREGA) BEGIN
            SET @V_AUX          = @V_AUXDIENTREGA - CONVERT(NUMERIC, @V_MINENTREGA);
            SET @V_DTMAXENTREGA = @V_DTMAXENTREGA - (7 * @V_AUX);
         END;
      END;

      WHILE DATEPART(DW, @V_DTMAXENTREGA) > 1 BEGIN
         SET @V_DTMAXENTREGA = @V_DTMAXENTREGA - 1;
      END;

      SET @V_DTAUX = @V_DTMAXENTREGA;
      DECLARE C_SEMANA CURSOR FOR
        SELECT
            ISNULL(DIASENTR.IDDOMPERIREC,'N') IDDOMPERIREC,
            ISNULL(DIASENTR.IDSEGPERIREC,'N') IDSEGPERIREC,
            ISNULL(DIASENTR.IDTERPERIREC,'N') IDTERPERIREC,
            ISNULL(DIASENTR.IDQUAPERIREC,'N') IDQUAPERIREC,
            ISNULL(DIASENTR.IDQUIPERIREC,'N') IDQUIPERIREC,
            ISNULL(DIASENTR.IDSEXPERIREC,'N') IDSEXPERIREC,
            ISNULL(DIASENTR.IDSABPERIREC,'N') IDSABPERIREC
         FROM DIASENTR
         WHERE DIASENTR.CDPERIENTR = @P_CDPERIENTR
         ORDER BY DIASENTR.DIENTREGA
      OPEN C_SEMANA;
      FETCH NEXT FROM C_SEMANA   INTO @V_SEMANA_IDDOMPERIREC,
                                      @V_SEMANA_IDSEGPERIREC,
                                      @V_SEMANA_IDTERPERIREC,
                                      @V_SEMANA_IDQUAPERIREC,
                                      @V_SEMANA_IDQUIPERIREC,
                                      @V_SEMANA_IDSEXPERIREC,
                                      @V_SEMANA_IDSABPERIREC;
      WHILE (@@FETCH_STATUS = 0)
      BEGIN
         IF @V_SEMANA_IDDOMPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         IF @V_SEMANA_IDSEGPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX + 1;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         IF @V_SEMANA_IDTERPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX + 2;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         IF @V_SEMANA_IDQUAPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX + 3;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         IF @V_SEMANA_IDQUIPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX + 4;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         IF @V_SEMANA_IDSEXPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX + 5;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         IF @V_SEMANA_IDSABPERIREC = 'S' BEGIN
            SET @V_DTAUX2 = @V_DTAUX + 6;
            WHILE (@V_DTAUX2 <= CONVERT(DATETIME, '31/12/'+@V_ANO, 103)) BEGIN
               SET @V_DTORIGINAL = @V_DTAUX2;
               IF @V_DTAUX2 >= @P_DTINICIAL BEGIN
                  /*- CALCULA UMA DATA DE ENTREGA ANTERIOR A UMA DATA NAO UTIL -*/
                  IF (@V_SOMENTEDIAUTIL = 'S') BEGIN
                     SET @V_CONTAUXI = 1;
                     WHILE (@V_CONTAUXI > 0) BEGIN
                       SELECT @V_CONTAUXI = COUNT(*)
                       FROM FERICOMP
                       WHERE
                       CDFILIAL   = @P_CDFILIAL AND
                       DTFERICOMP = @V_DTAUX2;
                       IF (@V_CONTAUXI > 0) BEGIN
                          SET @V_DTAUX2 = @V_DTAUX2 - 1;
                       END;
                     END;
                  END;
                  IF @V_DTAUX2 >= @P_DTPROCESSA BEGIN
                     INSERT INTO CALECOMP
                     (CDFILIAL, CDPERIENTR, DTENTREGA, DTANTPROXENT)
                     (SELECT
                         @P_CDFILIAL, @P_CDPERIENTR, @V_DTAUX2, @V_DTAUX2
                      FROM PARAMGERAL
                      WHERE NOT EXISTS (SELECT 1
                                        FROM CALECOMP
                                        WHERE CDFILIAL     = @P_CDFILIAL AND
                                              CDPERIENTR   = @P_CDPERIENTR AND
                                              DTENTREGA    = @V_DTAUX2));
                  END;
               END;
               SET @V_DTAUX2 = @V_DTORIGINAL;
               SET @V_DTAUX2 = @V_DTAUX2 + @V_INTERVALO;
            END;
         END;
         SET @V_DTAUX = @V_DTAUX + 7;
         FETCH NEXT FROM C_SEMANA   INTO @V_SEMANA_IDDOMPERIREC,
                                         @V_SEMANA_IDSEGPERIREC,
                                         @V_SEMANA_IDTERPERIREC,
                                         @V_SEMANA_IDQUAPERIREC,
                                         @V_SEMANA_IDQUIPERIREC,
                                         @V_SEMANA_IDSEXPERIREC,
                                         @V_SEMANA_IDSABPERIREC;
      END;
      CLOSE C_SEMANA;
      DEALLOCATE C_SEMANA;
      SET @VDATAPROX = NULL;
      DECLARE C_ANTPROXENTR CURSOR FOR
         SELECT
            C.CDFILIAL,
            C.CDPERIENTR,
            C.DTENTREGA
         FROM CALECOMP C
         WHERE CDFILIAL   = @P_CDFILIAL
           AND CDPERIENTR = @P_CDPERIENTR
           AND DTENTREGA  >= @P_DTPROCESSA
         ORDER BY DTENTREGA DESC
      OPEN C_ANTPROXENTR;
      FETCH NEXT FROM C_ANTPROXENTR  INTO @V_ANTPROXENTR_CDFILIAL,
                                          @V_ANTPROXENTR_CDPERIENTR,
                                          @V_ANTPROXENTR_DTENTREGA;
      WHILE (@@FETCH_STATUS = 0)
      BEGIN
          IF @VDATAPROX IS NULL BEGIN
              SET @VDATAPROX = @V_ANTPROXENTR_DTENTREGA;
          END
          ELSE BEGIN
              UPDATE CALECOMP
                 SET DTANTPROXENT = @VDATAPROX - 1
               WHERE CDFILIAL   = @V_ANTPROXENTR_CDFILIAL
                 AND DTENTREGA  = @V_ANTPROXENTR_DTENTREGA
                 AND CDPERIENTR = @V_ANTPROXENTR_CDPERIENTR;
              SET @VDATAPROX = @V_ANTPROXENTR_DTENTREGA;
          END;
          FETCH NEXT FROM C_ANTPROXENTR  INTO @V_ANTPROXENTR_CDFILIAL,
                                              @V_ANTPROXENTR_CDPERIENTR,
                                              @V_ANTPROXENTR_DTENTREGA;

      END;
      CLOSE C_ANTPROXENTR;
      DEALLOCATE C_ANTPROXENTR;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'SEMANAL_RECORRENTE_DTENTR','5.05.005';
GO
